==> huaweicloudsdkvss-3.0.82-py2.py3-none-any.whl: huaweicloudsdkvss/v3/model/list_business_risks_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListBusinessRisksResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[BusinessRiskItem]'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data'
    }

    def __init__(self, total=None, data=None):
        """ListBusinessRisksResponse - a model defined in huaweicloud sdk"""
        
        super(ListBusinessRisksResponse, self).__init__()

        self._total = None
        self._data = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if data is not None:
            self.data = data

    @property
    def total(self):
        """Gets the total of this ListBusinessRisksResponse.

        业务风险总数

        :return: The total of this ListBusinessRisksResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListBusinessRisksResponse.

        业务风险总数

        :param total: The total of this ListBusinessRisksResponse.
        :type: int
        """
        self._total = total

    @property
    def data(self):
        """Gets the data of this ListBusinessRisksResponse.

        业务风险列表

        :return: The data of this ListBusinessRisksResponse.
        :rtype: list[BusinessRiskItem]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ListBusinessRisksResponse.

        业务风险列表

        :param data: The data of this ListBusinessRisksResponse.
        :type: list[BusinessRiskItem]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBusinessRisksResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvss-3.0.105-py2.py3-none-any.whl: huaweicloudsdkvss/v3/model/list_business_risks_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListBusinessRisksResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[BusinessRiskItem]'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data'
    }

    def __init__(self, total=None, data=None):
        """ListBusinessRisksResponse

        The model defined in huaweicloud sdk

        :param total: 业务风险总数
        :type total: int
        :param data: 业务风险列表
        :type data: list[:class:`huaweicloudsdkvss.v3.BusinessRiskItem`]
        """
        
        super(ListBusinessRisksResponse, self).__init__()

        self._total = None
        self._data = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if data is not None:
            self.data = data

    @property
    def total(self):
        """Gets the total of this ListBusinessRisksResponse.

        业务风险总数

        :return: The total of this ListBusinessRisksResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListBusinessRisksResponse.

        业务风险总数

        :param total: The total of this ListBusinessRisksResponse.
        :type total: int
        """
        self._total = total

    @property
    def data(self):
        """Gets the data of this ListBusinessRisksResponse.

        业务风险列表

        :return: The data of this ListBusinessRisksResponse.
        :rtype: list[:class:`huaweicloudsdkvss.v3.BusinessRiskItem`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ListBusinessRisksResponse.

        业务风险列表

        :param data: The data of this ListBusinessRisksResponse.
        :type data: list[:class:`huaweicloudsdkvss.v3.BusinessRiskItem`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBusinessRisksResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
